#[repr(simd)]pub struct HvxVectorPair([i32; 32]);🔬This is a nightly-only experimental API. (
stdarch_hexagon #151523)Available on
target_arch=hexagon only.Expand description
HVX vector pair type (1024 bits / 128 bytes)
This type represents a pair of HVX vector registers, often used for operations that produce double-width results.
Tuple Fields
0: [i32; 32]🔬This is a nightly-only experimental API. (
stdarch_hexagon #151523)Implementations
Sourceimpl HvxVectorPair
impl HvxVectorPair
Sourcefn splat(value: i32) -> HvxVectorPair
🔬This is a nightly-only experimental API. (stdarch_hexagon #151523)
fn splat(value: i32) -> HvxVectorPair
stdarch_hexagon #151523)Put the same value in every lane.
Sourceconst fn as_array(&self) -> &[i32; 32]
🔬This is a nightly-only experimental API. (stdarch_hexagon #151523)
const fn as_array(&self) -> &[i32; 32]
stdarch_hexagon #151523)Returns an array reference containing the entire SIMD vector.
Sourcefn as_mut_array(&mut self) -> &mut [i32; 32]
🔬This is a nightly-only experimental API. (stdarch_hexagon #151523)
fn as_mut_array(&mut self) -> &mut [i32; 32]
stdarch_hexagon #151523)Returns a mutable array reference containing the entire SIMD vector.